@@ -1,12 +1,13 @@
+# frozen_string_literal: true
 module Molinillo
   # A state that a {Resolution} can be in
-  # @attr [String] name
-  # @attr [Array<Object>] requirements
-  # @attr [DependencyGraph] activated
-  # @attr [Object] requirement
-  # @attr [Object] possibility
-  # @attr [Integer] depth
-  # @attr [Set<Object>] conflicts
+  # @attr [String] name the name of the current requirement
+  # @attr [Array<Object>] requirements currently unsatisfied requirements
+  # @attr [DependencyGraph] activated the graph of activated dependencies
+  # @attr [Object] requirement the current requirement
+  # @attr [Object] possibilities the possibilities to satisfy the current requirement
+  # @attr [Integer] depth the depth of the resolution
+  # @attr [Set<Object>] conflicts unresolved conflicts
   ResolutionState = Struct.new(
     :name,
     :requirements,
@@ -17,6 +18,14 @@ module Molinillo
     :conflicts
   )
 
+  class ResolutionState
+    # Returns an empty resolution state
+    # @return [ResolutionState] an empty state
+    def self.empty
+      new(nil, [], DependencyGraph.new, nil, nil, 0, Set.new)
+    end
+  end
+
   # A state that encapsulates a set of {#requirements} with an {Array} of
   # possibilities
   class DependencyState < ResolutionState
